#name: C6X conformance attribute merging, none 11
#as: -mlittle-endian
#ld: -r -melf32_tic6x_le
#source: attr-conformance-none.s
#source: attr-conformance-11.s
#readelf: -A

Attribute Section: c6xabi
File Attributes
  Tag_ISA: C674x
